@@ -10,6 +10,8 @@ function(t.vec,d.vec,alpha,S.plot=TRUE,S.col="black"){
   A=log(  (exp(-alpha*(R-1)/n)-1)/(exp(-alpha*R/n)-1)  )
   A[n]=0
   S=-1/alpha*log(  1+(exp(-alpha)-1)*exp(cumsum(A* d.sort))  )
+  if(sum(S<=0.5)>=1){med=min(t.sort[S<=0.5])}else{med=Inf}
+
   if(S.plot==TRUE){
     plot(c(0,t.sort),c(1,S),type="s",lwd=3,
          ylim=c(0,1),ylab="Survival probability",xlab="Time",col=S.col)
@@ -17,5 +19,5 @@ function(t.vec,d.vec,alpha,S.plot=TRUE,S.col="black"){
   }
   func1=function(x){x/(exp(x)-1)}
   tau=1-4/alpha*(1-integrate(func1,0,alpha)$value/alpha)
-  list( tau=tau, time=t.sort, n.risk=R, surv=S )
+  list( tau=tau, median=med, time=t.sort, n.risk=R, surv=S )
 }
