@@ -9,6 +9,7 @@ function(t.vec,d.vec,alpha,S.plot=TRUE,S.col="black"){
   A=( -log((R-1)/n) )^(alpha+1)-( -log(R/n) )^(alpha+1)
   A[n]=0
   S=exp( -( cumsum(A*d.sort) )^(1/(1+alpha)) )
+  if(sum(S<=0.5)>=1){med=min(t.sort[S<=0.5])}else{med=Inf}
 
   if(S.plot==TRUE){
     plot(c(0,t.sort),c(1,S),type="s",lwd=3,
@@ -16,5 +17,5 @@ function(t.vec,d.vec,alpha,S.plot=TRUE,S.col="black"){
     points(t.sort[d.sort==0],S[d.sort==0],pch=3,cex=2,col=S.col)
   }
 
-  list( tau=(alpha/(alpha+1)), time=t.sort, n.risk=R, surv=S )
+  list( tau=(alpha/(alpha+1)), median=med, time=t.sort, n.risk=R, surv=S )
 }
